@@ -1,9 +1,9 @@
-/* $Id: events.c,v 1.72.2.2 2003/10/20 21:21:16 wojtekka Exp $ */
+/* $Id: events.c,v 1.77 2004/04/23 22:43:58 misiek Exp $ */
 
 /*
  *  (C) Copyright 2001-2003 Wojtek Kaniewski <wojtekka@irc.pl>
  *                          Robert J. Wony <speedy@ziew.org>
- *                          Arkadiusz Mikiewicz <misiek@pld.org.pl>
+ *                          Arkadiusz Mikiewicz <arekm@pld-linux.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License Version
@@ -1311,10 +1311,9 @@ struct gg_event *gg_watch_fd(struct gg_session *sess)
 				sess->fd = -1;
 				break;
 			}
-	
+
 			if (h->type != GG_WELCOME) {
 				gg_debug(GG_DEBUG_MISC, "// gg_watch_fd() invalid packet received\n");
-
 				free(h);
 				close(sess->fd);
 				sess->fd = -1;
@@ -1419,6 +1418,10 @@ struct gg_event *gg_watch_fd(struct gg_session *sess)
 				gg_debug(GG_DEBUG_MISC, "// gg_watch_fd() login failed\n");
 				e->event.failure = GG_FAILURE_PASSWORD;
 				errno = EACCES;
+			} else if (h->type == GG_NEED_EMAIL) {
+				gg_debug(GG_DEBUG_MISC, "// gg_watch_fd() email change needed\n");
+				e->event.failure = GG_FAILURE_NEED_EMAIL;
+				errno = EACCES;
 			} else {
 				gg_debug(GG_DEBUG_MISC, "// gg_watch_fd() invalid packet\n");
 				e->event.failure = GG_FAILURE_INVALID;
