@@ -1,9 +1,9 @@
-/* $Id: libgadu.h,v 1.166 2003/10/17 19:59:28 wojtekka Exp $ */
+/* $Id: libgadu.h,v 1.172 2004/05/02 20:19:55 wojtekka Exp $ */
 
 /*
  *  (C) Copyright 2001-2003 Wojtek Kaniewski <wojtekka@irc.pl>
  *                          Robert J. Wony <speedy@ziew.org>
- *                          Arkadiusz Mikiewicz <misiek@pld.org.pl>
+ *                          Arkadiusz Mikiewicz <arekm@pld-linux.org>
  *                          Tomasz Chiliski <chilek@chilan.com>
  *                          Piotr Wysocki <wysek@linux.bydg.org>
  *                          Dawid Jarosz <dawjar@poczta.onet.pl>
@@ -433,10 +433,9 @@ enum gg_failure_t {
 	GG_FAILURE_READING,		/* zerwano poczenie podczas odczytu */
 	GG_FAILURE_WRITING,		/* zerwano poczenie podczas zapisu */
 	GG_FAILURE_PASSWORD,		/* nieprawidowe haso */
-
 	GG_FAILURE_404, 		/* XXX nieuywane */
-
-	GG_FAILURE_TLS			/* bd negocjacji TLS */
+	GG_FAILURE_TLS,			/* bd negocjacji TLS */
+	GG_FAILURE_NEED_EMAIL 		/* serwer rozczy nas z prob o zmian emaila */
 };
 
 /*
@@ -866,6 +865,12 @@ extern char *gg_proxy_username;		/* okrela nazw uytkownika przy autoryzacji serw
 extern char *gg_proxy_password;		/* okrela haso uytkownika przy autoryzacji serwera proxy */
 extern int gg_proxy_http_only;		/* wcza obsug proxy wycznie dla usug HTTP */
 
+
+/* 
+ * adres, z ktrego lemy pakiety (np czymy si z serwerem)
+ * uywany przy gg_connect()
+ */
+extern unsigned long gg_local_ip; 
 /*
  * -------------------------------------------------------------------------
  * poniej znajduj si wewntrzne sprawy biblioteki. zwyky klient nie
@@ -934,7 +939,7 @@ int gg_image_queue_remove(struct gg_session *s, struct gg_image_queue *q, int fr
 #define GG_DEFAULT_PROTOCOL_VERSION 0x20
 #define GG_DEFAULT_TIMEOUT 30
 #define GG_HAS_AUDIO_MASK 0x40000000
-#define GG_LIBGADU_VERSION "1.4.20031117"
+#define GG_LIBGADU_VERSION "1.5.20040628"
 
 #define GG_DEFAULT_DCC_PORT 1550
 
@@ -944,6 +949,7 @@ struct gg_header {
 } GG_PACKED;
 
 #define GG_WELCOME 0x0001
+#define GG_NEED_EMAIL 0x0014
 
 struct gg_welcome {
 	uint32_t key;			/* klucz szyfrowania hasa */
@@ -1061,6 +1067,9 @@ struct gg_new_status {
 	uint32_t status;			/* na jaki zmieni? */
 } GG_PACKED;
 
+#define GG_NOTIFY_FIRST 0x000f
+#define GG_NOTIFY_LAST 0x0010
+
 #define GG_NOTIFY 0x0010
 	
 struct gg_notify {
@@ -1071,6 +1080,8 @@ struct gg_notify {
 #define GG_USER_OFFLINE 0x01	/* bdziemy niewidoczni dla uytkownika */
 #define GG_USER_NORMAL 0x03	/* zwyky uytkownik */
 #define GG_USER_BLOCKED 0x04	/* zablokowany uytkownik */
+
+#define GG_LIST_EMPTY 0x0012
 	
 #define GG_NOTIFY_REPLY 0x000c	/* tak, to samo co GG_LOGIN */
 	
