@@ -1,4 +1,4 @@
-/* $Id: ekg.c,v 1.310.2.2 2003/10/21 17:35:20 wojtekka Exp $ */
+/* $Id: ekg.c,v 1.324 2004/06/27 09:34:07 szalik Exp $ */
 
 /*
  *  (C) Copyright 2001-2003 Wojtek Kaniewski <wojtekka@irc.pl>
@@ -8,6 +8,7 @@
  *                          Dawid Jarosz <dawjar@poczta.onet.pl>
  *                          Wojciech Bojdo <wojboj@htcon.pl>
  *                          Piotr Domagalski <szalik@szalik.net>
+ *			    Piotr Kupisiewicz <deli@rzepaknet.us>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License Version 2 as
@@ -39,6 +40,9 @@
 #include <fcntl.h>
 #include <getopt.h>
 #include <limits.h>
+#ifdef HAVE_LOCALE_H
+#  include <locale.h>
+#endif
 #include <pwd.h>
 #include <signal.h>
 #include <stdarg.h>
@@ -173,16 +177,15 @@ static int get_char_from_pipe(struct gg_common *c)
 		return -1;
 	
 	if (ch != '\n' && ch != '\r') {
-		if (strlen(buf) < sizeof(buf) - 1)
+		if (strlen(buf) < sizeof(buf) - 2)
 			buf[strlen(buf)] = ch;
 	}
 
 	if (ch == '\n' && escaped) {	/* zamazuje \\ */
-		buf[strlen(buf) - 1] = '\r';
-		buf[strlen(buf) - 1] = '\n';
+		strcpy(buf + strlen(buf) - 1, "\r\n");
 	}
 
-	if ((ch == '\n' && !escaped) || (strlen(buf) >= sizeof(buf) - 1)) {
+	if ((ch == '\n' && !escaped) || (strlen(buf) >= sizeof(buf) - 2)) {
 		command_exec(NULL, buf, 0);
 		memset(buf, 0, sizeof(buf));
 	}
@@ -468,7 +471,7 @@ void ekg_wait_for_key()
 							addr.s_addr = u->ip.s_addr;
 							port = u->port;
 						}
-						tmp = saprintf("%s (%s:%d)", xstrdup(format_user(d->peer_uin)), inet_ntoa(addr), port);
+						tmp = saprintf("%s (%s:%d)", format_user(d->peer_uin), inet_ntoa(addr), port);
 					} else 
 						tmp = saprintf("%s:%d", inet_ntoa(addr), port);
 					print("dcc_timeout", tmp);
@@ -500,7 +503,7 @@ void ekg_wait_for_key()
 
 		/* timeout autoawaya */
 		if (config_auto_away && GG_S_A(config_status) && time(NULL) - last_action > config_auto_away && sess && sess->state == GG_STATE_CONNECTED) {
-			change_status(GG_STATUS_BUSY, NULL, config_auto_away);
+			change_status(GG_STATUS_BUSY, (config_auto_away_keep_descr) ? config_reason : NULL, 1);
 			in_auto_away = 1;
 		}
 
@@ -629,7 +632,7 @@ void ekg_wait_for_key()
 
 			if (c->type == GG_SESSION_USER0) {
 				if (config_auto_back == 2 && GG_S_B(config_status) && in_auto_away) {
-					change_status(GG_STATUS_AVAIL, NULL, 1);
+					change_status(GG_STATUS_AVAIL, (config_auto_away_keep_descr) ? config_reason : NULL, 1);
 					in_auto_away = 0;
 				}
 
@@ -949,6 +952,13 @@ int main(int argc, char **argv)
 
 	ekg_started = time(NULL);
 
+#ifdef HAVE_SETLOCALE
+	if (getenv("LC_ALL") || getenv("LC_COLLATE")) {
+		setlocale(LC_COLLATE, "");
+		strcoll_usable = 1;
+	}
+#endif
+
 #ifdef WITH_UI_READLINE
 	ui_init = ui_readline_init;
 #elif defined(WITH_UI_NCURSES)
@@ -1207,16 +1217,23 @@ int main(int argc, char **argv)
 	ui_event("xterm_update");
 	
 #ifdef WITH_IOCTLD
-	if (!batch_mode) {
+	if (!batch_mode && config_ioctld_enable > 0) {
+		
 		sock_path = prepare_path(".socket", 1);
 	
 		if (!(ioctld_pid = fork())) {
-			execl(ioctld_path, "ioctld", sock_path, (void *) NULL);
+			if (config_ioctld_enable == 1)
+				execl(ioctld_path, "ioctld", sock_path, (void *) NULL);
+			else if (config_ioctld_enable == 2) {
+				char *portstr = saprintf("%d", config_ioctld_net_port);
+				if (execl(ioctld_path, "ioctld", sock_path, portstr, (void*)NULL) == -1)
+					xfree(portstr);
+			}
 			exit(0);
 		}
 	
 		ioctld_socket(sock_path);
-	
+		
 		atexit(ioctld_kill);
 	}
 #endif /* WITH_IOCTLD */
@@ -1257,9 +1274,6 @@ int main(int argc, char **argv)
 	if (set_private)
 		config_status |= GG_STATUS_FRIENDS_MASK;
 
-	/* uaktualnij wszystko, co trzeba */
-	change_status(config_status, config_reason, 2);
-
 	/* jeli ma by theme, niech bdzie theme */
 	if (load_theme)
 		theme_read(load_theme, 1);
@@ -1477,6 +1491,7 @@ void ekg_exit()
 	list_destroy(autofinds, 1);
 
 	xfree(home_dir);
+	xfree(last_tokenid);
 
 	xfree(gg_proxy_host);
 	xfree(gg_proxy_username);
