@@ -1,10 +1,11 @@
-/* $Id: events.c,v 1.304.2.1 2003/10/20 21:21:19 wojtekka Exp $ */
+/* $Id: events.c,v 1.314 2004/06/25 14:41:55 szalik Exp $ */
 
 /*
  *  (C) Copyright 2001-2003 Wojtek Kaniewski <wojtekka@irc.pl>
  *                          Piotr Wysocki <wysek@linux.bydg.org>
  *                          Dawid Jarosz <dawjar@poczta.onet.pl>
  *                          Piotr Domagalski <szalik@szalik.net>
+ *                          Adam Czerwiski <acze@acze.net>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License Version 2 as
@@ -58,6 +59,7 @@
 #include "userlist.h"
 #include "voice.h"
 #include "xmalloc.h"
+#include "token.h"
 
 void handle_msg(), handle_ack(), handle_status(), handle_notify(),
 	handle_success(), handle_failure(), handle_search50(),
@@ -577,8 +579,6 @@ void handle_msg(struct gg_event *e)
 		return;
 	}
 #endif
-	
-
 
 	if (!(ignored_check(e->event.msg.sender) & IGNORE_EVENTS))
 		event_check((chat) ? EVENT_CHAT : EVENT_MSG, e->event.msg.sender, e->event.msg.message);
@@ -924,7 +924,7 @@ static void handle_common(uin_t uin, int status, const char *idescr, int dtime,
 			break;
 
 		/* zaloguj */
-		if (config_log_status && (!GG_S_D(s->status) || !descr))
+		if ((config_log_status == 1) && (!GG_S_D(s->status) || !descr))
 			put_log(uin, "status,%ld,%s,%s:%d,%s,%s\n", uin, ((u->display) ? u->display : ""), inet_ntoa(u->ip), u->port, log_timestamp(time(NULL)), s->log);
 		if (config_log_status && GG_S_D(s->status) && descr)
 		    	put_log(uin, "status,%ld,%s,%s:%d,%s,%s,%s\n", uin, ((u->display) ? u->display : ""), inet_ntoa(u->ip), u->port, log_timestamp(time(NULL)), s->log, descr);
@@ -1180,6 +1180,10 @@ void handle_success(struct gg_event *e)
  	}
 
 	hide_notavail = 1;
+	 
+	/* ustawiamy swj status */
+	change_status(config_status, config_reason, 2);
+
 
 	update_status();
 	update_status_myip();
@@ -1275,9 +1279,11 @@ void handle_pubdir(struct gg_http *h)
 		xfree(config_password);
 		config_password = reg_password;
 		reg_password = NULL;
-		xfree(config_email);
-		config_email = reg_email;
-		reg_email = NULL;
+		if (reg_email) {
+			xfree(config_email);
+			config_email = reg_email;
+			reg_email = NULL;
+		}
 	}
 
 	if (h->type == GG_SESSION_REGISTER) {
@@ -1327,6 +1333,64 @@ fail:
 	gg_free_pubdir(h);
 }
 
+/*
+ * token_check()
+ * 
+ * funkcja sprawdza czy w danym miejscu znajduje si zaproponowany znaczek
+ * 
+ *  - n - numer od 0 do 15 (znaczki od 0 do f)
+ *  - x, y - wsprzdne znaczka w tablicy ocr
+ */
+static int token_check(int nr, int x, int y, const char *ocr, int maxx, int maxy)
+{
+	int i;
+
+	for (i = nr * token_char_height; i < (nr + 1) * token_char_height; i++, y++) {
+		int j, xx = x;
+
+		for (j = 0; token_id[i][j] && j + xx < maxx; j++, xx++) {
+			if (token_id[i][j] != ocr[y * (maxx + 1) + xx])
+				return 0;
+		}
+	}
+  
+	return 1;
+}
+
+/*
+ * token_ocr()
+ *
+ * zwraca tre tokenu
+ */
+char *token_ocr(const char *ocr, int width, int height, int length)
+{
+	int x, y, count = 0;
+	char *token;
+
+	token = xmalloc(length + 1);
+	memset(token, 0, length + 1);
+		
+	for (x = 0; x < width; x++) {
+		for (y = 0; y < height - token_char_height; y++) {
+			int result = 0, token_part = 0;
+		      
+			do
+				result = token_check(token_part++, x, y, ocr, width, height);
+			while (!result && token_part < 16);
+			
+			if (result && count < length)
+				token[count++] = token_id_char[token_part - 1];
+		}
+	}
+
+	if (count == length)
+		return token;
+	
+	xfree(token);
+
+	return NULL;
+}
+
 /*
  * handle_token()
  *
@@ -1339,7 +1403,7 @@ fail:
 void handle_token(struct gg_http *h)
 {
 	struct gg_token *t = NULL;
-	char *file;
+	char *file = NULL;
 	int fd;
 
 	if (!h)
@@ -1383,8 +1447,9 @@ void handle_token(struct gg_http *h)
 		struct jpeg_error_mgr e;
 		JSAMPROW buf[1];
 		int size;
-		char *out;
+		char *token, *tmp;
 		FILE *f;
+		int h = 0;
 
 		if (!(f = fopen(file, "rb"))) {
 			print("token_failed", strerror(errno));
@@ -1399,29 +1464,41 @@ void handle_token(struct gg_http *h)
 
 		size = j.output_width * j.output_components;
 		buf[0] = xmalloc(size);
-		out = xmalloc(j.output_width + 1);
-		out[j.output_width] = 0;
-
+                
+                token = xmalloc((j.output_width + 1) * j.output_height);
+		
 		while (j.output_scanline < j.output_height) {
 			int i;
 
 			jpeg_read_scanlines(&j, buf, 1);
 
-			for (i = 0; i < j.output_width; i++)
-				out[i] = (buf[0][i*3] + buf[0][i*3+1] + buf[0][i*3+2] < 384) ? '#' : '.';
-
-			print("token_body", out);
+			for (i = 0; i < j.output_width; i++, h++)
+				token[h] = (buf[0][i*3] + buf[0][i*3+1] + buf[0][i*3+2] < 384) ? '#' : '.';
+			
+			token[h++] = 0;
 		}
 
+		if (!(tmp = token_ocr(token, j.output_width, j.output_height, t->length))) {
+			int i;
+
+			for (i = 0; i < j.output_height; i++)
+				print("token_body", token[i * (j.output_width + 1)]);
+		} else {
+			print("token_ocr", tmp);
+			xfree(tmp);
+		}
+
+		xfree(token);
+
 		jpeg_finish_decompress(&j);
 		jpeg_destroy_decompress(&j);
 
 		xfree(buf[0]);
-		xfree(out);
 		fclose(f);
+		
 		unlink(file);
 	} else
-#else
+#else	/* HAVE_LIBJPEG */
 	{
 		char *file2 = saprintf("%s.jpg", file);
 
@@ -1432,17 +1509,19 @@ void handle_token(struct gg_http *h)
 
 		xfree(file2);
 	}
-#endif
+#endif	/* HAVE_LIBJPEG */
 
-	xfree(file);
-
-#else
+#else	/* HAVE_MKSTEMP */
 	print("token_unsupported");
-#endif
+#endif	/* HAVE_MKSTEMP */
+
 
 fail:
+#ifdef HAVE_MKSTEMP
+	xfree(file);
+#endif
 	list_remove(&watches, h, 0);
-	gg_free_pubdir(h);
+	gg_token_free(h);
 }
 
 /*
@@ -1651,15 +1730,28 @@ void handle_dcc(struct gg_dcc *d)
 			break;
 
 		case GG_EVENT_DCC_CLIENT_ACCEPT:
+		{
+			struct userlist *u;
+			
 			gg_debug(GG_DEBUG_MISC, "## GG_EVENT_DCC_CLIENT_ACCEPT\n");
 			
-			if (!userlist_find(d->peer_uin, NULL) || config_uin != d->uin) {
+			if (!(u = userlist_find(d->peer_uin, NULL)) || config_uin != d->uin) {
 				gg_debug(GG_DEBUG_MISC, "## unauthorized client (uin=%ld), closing connection\n", d->peer_uin);
 				list_remove(&watches, d, 0);
 				gg_free_dcc(d);
 				return;
 			}
-			break;	
+
+			if (d->remote_addr != u->ip.s_addr) {
+				char tmp[20];
+
+				snprintf(tmp, sizeof(tmp), "%s", inet_ntoa(*((struct in_addr*) &d->remote_addr)));
+				
+				print("dcc_spoof", format_user(d->peer_uin), inet_ntoa(u->ip), tmp);
+			}
+
+			break;
+		}
 
 		case GG_EVENT_DCC_CALLBACK:
 		{
@@ -1801,6 +1893,8 @@ void handle_dcc(struct gg_dcc *d)
 				break;
 			}
 
+			event_check(EVENT_DCCFINISH, t->uin, t->filename);
+
 			print((t->dcc->type == GG_SESSION_DCC_SEND) ? "dcc_done_send" : "dcc_done_get", format_user(t->uin), t->filename);
 			
 			remove_transfer(d);
