@@ -1,4 +1,4 @@
-/* $Id: stuff.c,v 1.401 2003/09/30 21:13:21 wojtekka Exp $ */
+/* $Id: stuff.c,v 1.420 2004/06/19 20:43:44 szalik Exp $ */
 
 /*
  *  (C) Copyright 2001-2003 Wojtek Kaniewski <wojtekka@irc.pl>
@@ -6,6 +6,7 @@
  *                          Pawe Maziarz <drg@o2.pl>
  *                          Dawid Jarosz <dawjar@poczta.onet.pl>
  *                          Piotr Domagalski <szalik@szalik.net>
+ *                          Piotr Kupisiewicz <deli@rzepaknet.us>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License Version 2 as
@@ -69,6 +70,9 @@
 #include "userlist.h"
 #include "vars.h"
 #include "xmalloc.h"
+#ifdef WITH_PYTHON
+#  include "python.h"
+#endif
 
 #ifndef PATH_MAX
 #  define PATH_MAX _POSIX_PATH_MAX
@@ -94,8 +98,10 @@ int in_auto_away = 0;
 int config_auto_reconnect = 10;
 int reconnect_timer = 0;
 int config_auto_away = 600;
+int config_auto_away_keep_descr = 1;
 int config_auto_save = 0;
 int config_auto_find = 0;
+int config_auto_conference = 1;
 time_t last_save = 0;
 int config_display_color = 1;
 int config_beep = 1;
@@ -114,6 +120,7 @@ char *config_sound_app = NULL;
 int config_uin = 0;
 int config_last_sysmsg = 0;
 int config_last_sysmsg_changed = 0;
+char *config_local_ip = NULL;
 char *config_password = NULL;
 int config_sms_away = 0;
 int config_sms_away_limit = 0;
@@ -177,6 +184,8 @@ char *config_windows_layout = NULL;
 char *config_profile = NULL;
 int config_header_size = 0;
 int config_statusbar_size = 1;
+int config_statusbar_fgcolor = 7;
+int config_statusbar_bgcolor = 4;
 char *config_proxy_forwarding = NULL;
 int config_password_cp1250 = 0;
 char *config_interface = NULL;
@@ -189,6 +198,10 @@ int config_wap_enabled = 2;
 #ifdef HAVE_LIBJPEG
 int config_display_token = 1;
 #endif
+#ifdef WITH_IOCTLD
+int config_ioctld_enable = 1;
+int config_ioctld_net_port = 22004;
+#endif
 
 char *last_search_first_name = NULL;
 char *last_search_last_name = NULL;
@@ -215,6 +228,7 @@ struct event_label event_labels[EVENT_LABELS_COUNT + 2] = {
 	{ EVENT_QUEUED, "queued" },
 	{ EVENT_NEWMAIL, "newmail" },
 	{ EVENT_BLOCKED, "blocked" },
+	{ EVENT_DCCFINISH, "dccfinish" },
 
 	{ INACTIVE_EVENT, NULL },
 	{ 0, NULL }
@@ -443,6 +457,7 @@ void binding_list(int quiet, const char *name, int all)
 	}
 }
 
+
 /*
  * binding_free()
  *
@@ -525,6 +540,7 @@ char *buffer_flush(int type, const char *target)
 			continue;
 
 		string_append(str, b->line);
+                string_append_c(str, '\r');
 		string_append_c(str, '\n');
 
 		xfree(b->line);
@@ -619,6 +635,20 @@ void changed_auto_save(const char *var)
 	last_save = time(NULL);
 }
 
+/*
+ * changed_aspell()
+ *
+ * wywoywane po zmianie wartoci zmiennej ,,aspell'' lub ,,aspell_lang'' lub ,,aspell_encoding''.
+ */
+#ifdef WITH_ASPELL
+void changed_aspell(const char *var)
+{
+	/* probujemy zainicjowac jeszcze raz aspell'a */
+	spellcheck_init();
+}
+#endif
+
+
 /*
  * changed_backlog_size()
  *
@@ -688,6 +718,31 @@ void changed_dcc(const char *var)
 	}
 }
 
+/*
+ * changed_local_ip()
+ *
+ * funkcja wywoywana przy zmianie wartoci zmiennej ,,local_ip''.
+ */
+void changed_local_ip(const char *var)
+{
+	if (config_local_ip == NULL)
+		gg_local_ip = htonl(INADDR_ANY);
+	else {
+#ifdef HAVE_INET_PTON
+		int tmp = inet_pton(AF_INET, config_local_ip, &gg_local_ip);
+		
+		if (tmp == 0 || tmp == -1) {
+		    	print("invalid_local_ip");
+			xfree(config_local_ip);
+		        config_local_ip = NULL;
+			gg_local_ip = htonl(INADDR_ANY);
+		}
+#else
+		gg_local_ip = inet_addr(config_local_ip);
+#endif
+	}
+}
+
 /*
  * changed_mesg()
  *
@@ -836,7 +891,7 @@ struct conference *conference_add(const char *name, const char *nicklist, int qu
 		return NULL;
 	}
 
-	nicks = array_make(nicklist, " ,", 0, 1, 0);
+	nicks = array_make(nicklist, " ,", 0, 1, 1);
 
 	/* grupy zamieniamy na niki */
 	for (i = 0; nicks[i]; i++) {
@@ -856,9 +911,10 @@ struct conference *conference_add(const char *name, const char *nicklist, int qu
 					struct group *g = m->data;
 
 					if (!strcasecmp(gname, g->name)) {
-						if (first++)
-							array_add(&nicks, xstrdup(u->display));
-						else {
+						if (first++) {
+							if (!array_contains(nicks, u->display, 0))
+								array_add(&nicks, xstrdup(u->display));
+						} else {
 							xfree(nicks[i]);
 							nicks[i] = xstrdup(u->display);
 						}
@@ -870,14 +926,15 @@ struct conference *conference_add(const char *name, const char *nicklist, int qu
 				}
 			}
 
-			xfree(gname);
-
 			if (!nig) {
 				printq("group_empty", gname);
 				printq("conferences_not_added", name);
+				xfree(gname);
 				array_free(nicks);
 				return NULL;
 			}
+			xfree(gname);
+
 		}
 	}
 
@@ -900,7 +957,7 @@ struct conference *conference_add(const char *name, const char *nicklist, int qu
 
 		if (!strcmp(*p, ""))
 		        continue;
-
+	
 		if (!(uin = get_uin(*p))) {
 			printq("user_not_found", *p);
 			continue;
@@ -1868,6 +1925,22 @@ void iso_to_ascii(unsigned char *buf)
 	}
 }
 
+/*
+ * strip_chars()
+ *
+ * pozbywa si podanego znaku na pocztku i kocu ancucha
+ */
+char *strip_chars(char *line, unsigned char what)
+{
+	while (*line == what)
+		line++;
+
+        if (line[strlen(line) - 1] == what)
+        	line[strlen(line) - 1] = 0;
+
+        return line;
+}
+
 /*
  * strip_spaces()
  *
@@ -1875,14 +1948,7 @@ void iso_to_ascii(unsigned char *buf)
  */
 char *strip_spaces(char *line)
 {
-	char *buf;
-	
-	for (buf = line; xisspace(*buf); buf++);
-
-	while (xisspace(line[strlen(line) - 1]))
-		line[strlen(line) - 1] = 0;
-	
-	return buf;
+	return strip_chars(line, ' ');
 }
 
 /*
@@ -2267,6 +2333,8 @@ int ioctld_parse_seq(const char *seq, struct action_data *data)
 	return 0;
 }
 
+
+
 /*
  * ioctld_socket()
  *
@@ -2746,14 +2814,15 @@ fail:
  *  - reason - opis stanu, moe by NULL.
  *  - autom - czy zmiana jest automatyczna?
  */
-void change_status(int status, const char *arg, int autom)
+void change_status(int status, const char *xarg, int autom)
 {
 	const char *filename, *config_x_reason, *format, *format_descr, *auto_format = NULL, *auto_format_descr = NULL;
 	int random_mask, status_descr;
-	char *reason = NULL, *tmp = NULL;
+	char *reason = NULL, *tmp = NULL, *arg;
 	int private_mask = (GG_S_F(config_status) ? GG_STATUS_FRIENDS_MASK : 0);
 
 	status = GG_S(status);
+	arg = xstrdup(xarg);
 
 	switch (status) {
 		case GG_STATUS_BUSY:
@@ -2800,10 +2869,30 @@ void change_status(int status, const char *arg, int autom)
 			return;
 	}
 
-	if (!(autom % 60))
-		tmp = saprintf("%dm", autom / 60);
+#ifdef WITH_PYTHON
+	PYTHON_HANDLE_HEADER(status_own, "(is)", status, arg)
+	{
+		char *a;
+
+		PYTHON_HANDLE_RESULT("is", &status, &a)
+		{
+			xfree(arg);
+			arg = xstrdup(a);
+		}
+	}
+
+	PYTHON_HANDLE_FOOTER()
+
+	if (!python_handle_result) {
+		xfree(arg);
+		return;
+	}
+#endif
+
+	if (!(config_auto_away % 60))
+		tmp = saprintf("%dm", config_auto_away / 60);
 	else
-		tmp = saprintf("%ds", autom);
+		tmp = saprintf("%ds", config_auto_away);
 								
 	if (!arg) {
 		if (config_random_reason & random_mask) {
@@ -2878,6 +2967,7 @@ void change_status(int status, const char *arg, int autom)
 	}
 	
 	xfree(tmp);
+	xfree(arg);
 
 	update_status();
 }
