@@ -1,4 +1,4 @@
-/* $Id: stuff.h,v 1.234 2003/09/30 21:13:22 wojtekka Exp $ */
+/* $Id: stuff.h,v 1.246 2004/06/19 19:25:33 deletek Exp $ */
 
 /*
  *  (C) Copyright 2001-2003 Wojtek Kaniewski <wojtekka@irc.pl>
@@ -59,12 +59,13 @@ enum event_t {
 	EVENT_QUEUED = TOGGLE_BIT(15),
 	EVENT_NEWMAIL = TOGGLE_BIT(16),
 	EVENT_BLOCKED = TOGGLE_BIT(17),
+	EVENT_DCCFINISH = TOGGLE_BIT(18),
 
-	EVENT_ALL = TOGGLE_BIT(18) - 1,
-	INACTIVE_EVENT = TOGGLE_BIT(18)
+	EVENT_ALL = TOGGLE_BIT(19) - 1,
+	INACTIVE_EVENT = TOGGLE_BIT(19)
 };
 
-#define EVENT_LABELS_COUNT 17	/* uaktualni ! */
+#define EVENT_LABELS_COUNT 18	/* uaktualni ! */
 struct event_label event_labels[EVENT_LABELS_COUNT + 2];
 
 struct event_label {
@@ -202,10 +203,17 @@ int mesg_startup;
 char *config_audio_device;
 char *config_away_reason;
 int config_auto_away;
+int config_auto_away_keep_descr;
 int config_auto_back;
 int config_auto_find;
+int config_auto_conference;
 int config_auto_reconnect;
 int config_auto_save;
+#ifdef WITH_ASPELL
+int config_aspell;
+char *config_aspell_lang;
+char *config_aspell_encoding;
+#endif
 char *config_back_reason;
 int config_beep;
 int config_beep_msg;
@@ -251,6 +259,7 @@ int config_last;
 int config_last_size;
 int config_last_sysmsg;
 int config_last_sysmsg_changed;
+char *config_local_ip;
 int config_log;
 int config_log_ignored;
 char *config_log_path;
@@ -287,6 +296,8 @@ char *config_sound_mail_file;
 char *config_speech_app;
 int config_status;
 int config_statusbar_size;
+int config_statusbar_fgcolor;
+int config_statusbar_bgcolor;
 char *config_tab_command;
 char *config_theme;
 int config_time_deviation;
@@ -297,6 +308,10 @@ int config_windows_save;
 #ifdef WITH_WAP
 int config_wap_enabled;
 #endif
+#ifdef WITH_IOCTLD
+int config_ioctld_enable;
+int config_ioctld_net_port;
+#endif
 
 char *home_dir;
 char *config_dir;
@@ -330,6 +345,8 @@ uin_t last_search_uin;
 
 char *last_tokenid;
 
+int strcoll_usable;
+
 int alias_add(const char *string, int quiet, int append);
 int alias_remove(const char *name, int quiet);
 void alias_free();
@@ -347,8 +364,12 @@ char *buffer_tail(int type);
 void buffer_free();
 
 void changed_auto_save(const char *var);
+#ifdef WITH_ASPELL
+void changed_aspell(const char *var);
+#endif
 void changed_backlog_size(const char *var);
 void changed_dcc(const char *var);
+void changed_local_ip(const char *var);
 void changed_mesg(const char *var);
 void changed_proxy(const char *var);
 void changed_theme(const char *var);
@@ -386,6 +407,7 @@ int msg_encrypt(uin_t uin, unsigned char **msg);
 void cp_to_iso(unsigned char *buf);
 void iso_to_cp(unsigned char *buf);
 void iso_to_ascii(unsigned char *buf);
+char *strip_chars(char *line, unsigned char what); 
 char *strip_spaces(char *line);
 
 int play_sound(const char *sound_path);
@@ -441,4 +463,8 @@ int ekg_hide_descr_status(int status);
 void ekg_wait_for_key();
 void ekg_exit();
 
+#ifdef WITH_ASPELL
+void spellcheck_init(void);
+#endif
+
 #endif /* __STUFF_H */
