@@ -1,7 +1,8 @@
-/* $Id: themes.c,v 1.313 2003/09/30 21:50:39 wojtekka Exp $ */
+/* $Id: themes.c,v 1.318 2004/04/28 09:12:49 wojtekka Exp $ */
 
 /*
  *  (C) Copyright 2001-2002 Wojtek Kaniewski <wojtekka@irc.pl>
+ * 			    Piotr Kupisiewicz <deli@rzepaknet.us>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License Version 2 as
@@ -858,6 +859,7 @@ void theme_init()
 	format_add("ncurses_prompt_query", "[%1] ", 1);
 	format_add("statusbar", " %c(%w%{time}%c)%w %{?uin %c(%w%{?!nick uin}%{nick}%c/%{?away %w}%{?avail %W}%{?invisible %K}%{?notavail %k}%{uin}%c) }%c%{?window (%wwin%c/%w%{window}}%{?query %c:%W%{query}}%{?debug %c(%Cdebug}%c)%w%{?activity  %c(%wact%c/%w}%{activity}%{?activity %c)%w}%{?mail  %c(%wmail%c/%w}%{mail}%{?mail %c)}%{?more  %c(%Gmore%c)}", 1);
 	format_add("header", " %{?query %c(%{?query_away %w}%{?query_avail %W}%{?query_invisible %K}%{?query_notavail %k}%{query}%{?query_descr %c/%w%{query_descr}}%c) %{?query_ip (%wip%c/%w%{query_ip}%c)}}%{?!query %c(%wekg%c/%w%{version}%c) (%w%{url}%c)}", 1);
+	format_add("ncurses_timestamp", "%H:%M", 1);
 
 	/* dla funkcji format_user() */
 	format_add("known_user", "%T%1%n/%2", 1);
@@ -1071,16 +1073,17 @@ void theme_init()
 	format_add("conn_stopped", "%! Przerwano czenie\n", 1);
 	format_add("conn_timeout", "%! Przekroczono limit czasu operacji czenia z serwerem\n", 1);
 	format_add("connected", "%> Poczono\n", 1);
-	format_add("connected_descr", "%> Poczono: %T%1%n%2\n", 1);
+	format_add("connected_descr", "%> Poczono: %T%1%n\n", 1);
 	format_add("disconnected", "%> Rozczono\n", 1);
-	format_add("disconnected_descr", "%> Rozczono: %T%1%n%2\n", 1);
+	format_add("disconnected_descr", "%> Rozczono: %T%1%n\n", 1);
 	format_add("already_connected", "%! Klient jest ju poczony. Wpisz %Treconnect%n aby poczy ponownie\n", 1);
 	format_add("during_connect", "%! czenie trwa. Wpisz %Tdisconnect%n aby przerwa\n", 1);
 	format_add("conn_broken", "%! Poczenie zostao przerwane\n", 1);
 	format_add("conn_disconnected", "%! Serwer zerwa poczenie\n", 1);
 	format_add("not_connected", "%! Brak poczenia z serwerem. Wpisz %Tconnect%n\n", 1);
 	format_add("not_connected_msg_queued", "%! Brak poczenia z serwerem. Wiadomo bdzie wysana po poczeniu.%n\n", 1);
-
+	format_add("invalid_local_ip", "%! Nieprawidowy adres lokalny.\n", 1);
+	
 	/* obsuga motyww */
 	format_add("theme_loaded", "%> Wczytano motyw %T%1%n\n", 1);
 	format_add("theme_default", "%> Ustawiono domylny motyw\n", 1);
@@ -1127,6 +1130,7 @@ void theme_init()
 	
 	/* pobieranie tokenu */
 	format_add("token", "%> Token zapisano do pliku %T%1%n\n", 1);
+	format_add("token_ocr", "%> Token: %T%1%n\n", 1);
 	format_add("token_body", "%1\n", 1);
 	format_add("token_failed", "%! Bd pobierania tokenu: %1\n", 1);
 	format_add("token_timeout", "%! Przekroczono limit czasu pobierania tokenu\n", 1);
@@ -1255,6 +1259,7 @@ void theme_init()
 
 	/* poczenia bezporednie */
 	format_add("dcc_attack", "%! %|Program otrzyma zbyt wiele da bezporednich pocze, ostatnie od %1\n", 1);
+	format_add("dcc_spoof", "%! %|Uytkownik %1 poda serwerowi adres %T%2%n, ale poczy si z nami z adresu %T%3%n. Moliwe, e kto prbuje si pod niego podszy. Zachowaj ostrono!\n", 1);
 	format_add("dcc_limit", "%! %|Przekroczono limit bezporednich pocze i dla bezpieczestwa zostay one wyczone. Aby je wczy ponownie, naley wpisa polecenie %Tset dcc 1%n i poczy si ponownie. Limit mona zmieni za pomoc zmiennej %Tdcc_limit%n.\n", 1);
 	format_add("dcc_create_error", "%! Nie mona wczy pocze bezporednich: %1\n", 1);
 	format_add("dcc_error_network", "%! Bd transmisji z %1\n", 1);
@@ -1415,6 +1420,7 @@ void theme_init()
 	format_add("http_failed_reading", "Serwer zerwa poczenie", 1);
 	format_add("http_failed_writing", "Serwer zerwa poczenie", 1);
 	format_add("http_failed_memory", "Brak pamici", 1);
+	
 
 #ifdef HAVE_OPENSSL
 	/* szyfrowanie */
