@@ -1,4 +1,4 @@
-/* $Id: ui-readline.c,v 1.126 2003/06/27 09:04:19 wojtekka Exp $ */
+/* $Id: ui-readline.c,v 1.127 2003/11/05 20:25:38 wojtekka Exp $ */
 
 /*
  *  (C) Copyright 2001-2003 Wojtek Kaniewski <wojtekka@irc.pl>
@@ -427,6 +427,20 @@ static char *python_generator(char *text, int state)
 	return NULL;
 }
 
+static char *reason_generator(char *text, int state)
+{
+	static int len;
+
+	if (!state) {
+		len = strlen(text);
+
+		if (config_reason && !strncasecmp(text, config_reason, len))
+			return xstrdup(config_reason);
+	}
+
+	return NULL;
+}
+
 static char *empty_generator(char *text, int state)
 {
 	return NULL;
@@ -559,6 +573,9 @@ static char **my_completion(char *text, int start, int end)
 					case 'w':
 						func = window_generator;
 						break;
+					case 'r':
+						func = reason_generator;
+						break;
 					default:
 						func = empty_generator;
 						break;
