@@ -1,4 +1,4 @@
-/* $Id: userlist.c,v 1.86 2003/07/22 16:20:21 wojtekka Exp $ */
+/* $Id: userlist.c,v 1.90 2004/02/13 01:25:18 wojtekka Exp $ */
 
 /*
  *  (C) Copyright 2001-2003 Wojtek Kaniewski <wojtekka@irc.pl>
@@ -83,7 +83,12 @@ static int userlist_compare(void *data1, void *data2)
 	if (!a || !a->display || !b || !b->display)
 		return 1;
 
-	return strcasecmp(a->display, b->display);
+#ifdef HAVE_STRCOLL
+	if (strcoll_usable)
+		return strcoll(a->display, b->display);
+	else
+#endif
+		return strcasecmp(a->display, b->display);
 }
 
 /*
@@ -492,7 +497,7 @@ void userlist_clear_status(uin_t uin)
 void userlist_clear()
 {
 	while (userlist)
-		userlist_remove(userlist->data);
+		userlist_remove(userlist->data, 1);
 }
 
 /*
@@ -521,14 +526,49 @@ struct userlist *userlist_add(uin_t uin, const char *display)
  *
  * usuwa danego uytkownika z listy kontaktw.
  *
- *  - u.
+ *  - u
+ *  - full - pene usuwanie? w przeciwnym wypadku zostawi uytkownikw
+ *           ignorowanych i blokowanych,
  */
-int userlist_remove(struct userlist *u)
+int userlist_remove(struct userlist *u, int full)
 {
+	int metagroups = 0;
 	list_t l;
 
 	if (!u)
 		return -1;
+
+	for (l = u->groups; l; l = l->next) {
+		struct group *g = l->data;
+
+		if (!strncmp(g->name, "__", 2))
+			metagroups = 1;
+	}
+
+	if (!full && (group_member(u, "__blocked") || ignored_check(u->uin))) {
+		xfree(u->first_name); u->first_name = NULL;
+		xfree(u->last_name); u->last_name = NULL;
+		xfree(u->nickname); u->nickname = NULL;
+		xfree(u->display); u->display = NULL;
+		xfree(u->mobile); u->mobile = NULL;
+		xfree(u->descr); u->descr = NULL;
+		xfree(u->foreign); u->foreign = NULL;
+		xfree(u->last_descr); u->last_descr = NULL;
+		xfree(u->email); u->email = NULL;
+
+		for (l = u->groups; l; ) {
+			struct group *g = l->data;
+
+			l = l->next;
+
+			if (strncmp(g->name, "__", 2)) {
+				xfree(g->name);
+				list_remove(&u->groups, g, 1);
+			}
+		}
+
+		return 0;
+	}
 	
 	xfree(u->first_name);
 	xfree(u->last_name);
@@ -697,7 +737,7 @@ int valid_nick(const char *nick)
 			return 0;
 	}
 
-	if (nick[0] == '@' || nick[0] == '#' || strchr(nick, ','))
+	if (nick[0] == '@' || nick[0] == '#')
 		return 0;
 
 	return 1;
@@ -785,7 +825,7 @@ int ignored_remove(uin_t uin)
 	}
 
 	if (!u->display && !u->groups) {
-		userlist_remove(u);
+		userlist_remove(u, 1);
 		return 0;
 	}
 
@@ -950,7 +990,7 @@ int blocked_remove(uin_t uin)
 	}
 
 	if (!u->display && !u->groups)
-		userlist_remove(u);
+		userlist_remove(u, 1);
 	else
 		gg_add_notify_ex(sess, u->uin, userlist_type(u));
 
@@ -995,16 +1035,27 @@ void userlist_send()
 	char *types;
         int i, count;
 
-	count = list_count(userlist);
+	for (count = 0, l = userlist; l; l = l->next) {
+		struct userlist *u = l->data;
 
+		if (!u->display && userlist_type(u) == GG_USER_NORMAL)
+			continue;
+
+		count++;
+	}
+		
         uins = xmalloc(count * sizeof(uin_t));
 	types = xmalloc(count * sizeof(char));
 
-	for (i = 0, l = userlist; l; i++, l = l->next) {
+	for (i = 0, l = userlist; l; l = l->next) {
 		struct userlist *u = l->data;
 
+		if (!u->display && userlist_type(u) == GG_USER_NORMAL)
+			continue;
+
                 uins[i] = u->uin;
 		types[i] = userlist_type(u);
+		i++;
 	}
 
         gg_notify_ex(sess, uins, types, count);
